##  Automatic Linking of Discovered Applications to Fact Sheets
There are two ways to link discovered applications to fact sheets. Automatic linking takes place in the following cases:
  * The application’s name on the fact sheet identically matches the discovered SaaS item (discovered SaaS application).
  * The fact sheet is already linked to a reference catalog item corresponding to the discovered SaaS item. To learn more, see [Applications in the Reference Catalog](https://help.sap.com/docs/leanix/ea/applications-in-reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD "By using reference data for application fact sheets, you can increase standardization and data quality, as well as set relations to other fact sheets for best-practice modeling.").


From the Settings at the top right corner of the list, you can toggle off the Auto-linking option to disable automatic linking. If you turn auto-linking on again later, only the SaaS items that are discovered after re-enabling are automatically linked.
